import logging

import click

from worker.cmd.hello import hello as worker_hello
from worker.cmd.join import join as worker_join

logging.basicConfig(
    format='%(asctime)s %(levelname)-8s %(message)s',
    level=logging.INFO,
    datefmt='%Y-%m-%d %H:%M:%S')


@click.group()
def cli():
    pass


@cli.command()
@click.option("--master-endpoint", help="Endpoint of master agent endpoint.", type=click.STRING, required=True)
def hello(master_endpoint):
    worker_hello(master_endpoint)


@cli.command()
@click.option("--master-endpoint", help="Endpoint of master agent endpoint", type=click.STRING, required=True)
def join(master_endpoint):
    worker_join(master_endpoint)


if __name__ == "__main__":
    cli()



import json
import os
import subprocess
import logging

import requests


def join(endpoint):
    uri = f"http://{endpoint}/join" # TODO: insecure -> https로 바꿀 것
    response = requests.post(uri)
    join_info = response.json()
    join_info['API_SERVER_ADDR'] = endpoint.split(':')[0]

    # Run install-master script from internet
    install(join_info)


def install(join_info):
    logging.info("[INSTALL]")
    env = dict(os.environ, **join_info)
    command = "cd /tmp && curl -s https://raw.githubusercontent.com/AI-Ocean/kubernetes-install-scripts/main/install-worker.sh | bash"
    process = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=env)

    # print progress
    while True:
        output = process.stdout.readline()
        if output == b'' and process.poll() is not None:
            break
        if output:
            print(output.strip().decode())

    print(process.stderr.readline().decode())




import logging
import json

import requests


def hello(endpoint):
    uri = f"http://{endpoint}/hello" # TODO: insecure -> https로 바꿀 것
    message = {"message": "What' your name?"}

    response = requests.get(uri, params=json.dumps(message))
    logging.info(response.json())


from setuptools import setup, find_packages
from os import environ

setup_requires = [
]

install_requires = [
    'websockets',
    'click',
    'requests'
]

dependency_links = [
]

setup(
    name='Ocean-Agent-Worker',
    version=environ["AGENT_VERSION"],
    description='Ocean-Agent for Worker nodes',
    author='kairos03',
    author_email='kairos9603@gmail.com',
    packages=find_packages(),
    install_requires=install_requires,
    setup_requires=setup_requires,
    dependency_links=dependency_links,
    scripts=[],
    entry_points={
        'console_scripts': [
            'agent-worker = worker.main:cli'
            ],
        },
    )